import requests  # type: ignore
import json
from requests.auth import HTTPBasicAuth  # type: ignore


def get_user_id_by_email(email):
    print(f"Searching for user ID with email {email}")
    with open("config.json", "r") as file:
        config = json.load(file)

    # Get token
    token_url = f"{config['keycloak_url']}/realms/master/protocol/openid-connect/token"
    token_data = {
        "grant_type": "password",
        "username": config["admin_username"],
        "password": config["admin_password"],
    }

    print("-- Get token")
    try:
        response = requests.post(
            token_url,
            data=token_data,
            auth=HTTPBasicAuth(config["client_id"], config["client_secret"]),
        )
        response.raise_for_status()
    except requests.exceptions.HTTPError as e:
        print(f"Error getting token: {e}")
        return None

    access_token = response.json()["access_token"]
    headers = {
        "Authorization": f"Bearer {access_token}",
        "Content-Type": "application/json",
    }

    # Search for user by email
    users_url = f"{config['keycloak_url']}/admin/realms/master/users"
    params = {"email": email, "exact": "true"}

    print("-- Search for user by email")
    try:
        response = requests.get(users_url, headers=headers, params=params)
        response.raise_for_status()
        users = response.json()

        # If user with this email exists, return their ID
        if len(users) > 0:
            user_id = users[0]["id"]
            print(f"-- Found user ID: {user_id}")
            return user_id
        else:
            print("-- No user found with this email")
            return None
    except requests.exceptions.HTTPError as e:
        print(f"Error searching for user: {e}")
        return None
